package cz.frantovo.rozsireneAtributy;

import java.io.File;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.nio.charset.Charset;
import java.nio.file.Path;
import java.nio.file.attribute.UserDefinedFileAttributeView;
import java.util.List;

/**
 * http://freedesktop.org/wiki/CommonExtendedAttributes
 * http://download.oracle.com/javase/tutorial/essential/io/fileAttr.html#user
 * http://today.java.net/pub/a/today/2008/07/03/jsr-203-new-file-apis.html#so-what-is-a-path-really
 *
 * $ setfattr -n user.fiki.pozdrav -v 'Dobrý den!' pokus.txt
 *
 * @author fiki
 */
public class PokusnýVýpis {

	/**
	 * Vypíše rozšířené atributy souboru.
	 * @param args pole s jedním prvkem – názvem souboru
	 * @throws IOException
	 */
	public static void main(String[] args) throws IOException {
		File soubor = new File(args[0]);
		Path cesta = soubor.toPath();
		UserDefinedFileAttributeView pohled = cesta.getFileAttributeView(UserDefinedFileAttributeView.class);
		List<String> jménaAtributů = pohled.list();
		for (String jménoAtributu : jménaAtributů) {
			ByteBuffer bajty = ByteBuffer.allocate(pohled.size(jménoAtributu));
			pohled.read(jménoAtributu, bajty);
			String hodnotaAtributu = dekóduj(bajty);
			System.out.println(jménoAtributu + " = " + hodnotaAtributu);
		}
	}

	private static String dekóduj(ByteBuffer bajty) {
		bajty.flip();
		return Charset.defaultCharset().decode(bajty).toString();
	}
}
